# DLTK SDK (Python)
[![Python 3.5](https://img.shields.io/badge/python-3.5-blue.svg)](https://www.python.org/downloads/release/python-350/)


[![](https://github.com/dltk-ai/dltkai-sdk/blob/master/python/dltk.png)](https://dltk.ai/)

DLTK renders a comprehensive spectrum of solutions that can be accessed by users on-demand from our pool of transformational technologies.

### Installation

DLTK SDK requires Python 3.5 + .

Install the dltk library: 
```
pip install -U dltkai
```

```sh
from dltkai.NaturalLanguage import sentiment_detect
response = sentiment_detect('I am feeling good.')
print(response)
```

For more details, visit https://dltk.ai/
